pub struct PipelineCompilationOptions<'a> {
pub constants: &'a [(&'a str, f64)],
pub zero_initialize_workgroup_memory: bool,
}Expand description
Advanced options for use when a pipeline is compiled
This implements Default, and for most users can be set to Default::default()
Fields
constants: &'a [(&'a str, f64)]Specifies the values of pipeline-overridable constants in the shader module.
If an @id attribute was specified on the declaration,
the key must be the pipeline constant ID as a decimal ASCII number; if not,
the key must be the constant’s identifier name.
If the given constant is specified more than once, the last value specified is used.
The value may represent any of WGSL’s concrete scalar types.
The default value is &[].
zero_initialize_workgroup_memory: boolWhether workgroup scoped memory will be initialized with zero values for this stage.
This is required by the WebGPU spec, but may have overhead which can be avoided for cross-platform applications
The default value is true.
Implementations
Sourceimpl PipelineCompilationOptions<'_>
impl PipelineCompilationOptions<'_>
Sourcepub const fn default() -> Self
pub const fn default() -> Self
This function is identical to Default::default() except that it is a const fn.